==> haskell-deque-0.4.4.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-rUglwstkWzKtFUyscc0o6
key:                  deque-0.4.4.1-rUglwstkWzKtFUyscc0o6
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  d1e77d6898f28ca027224eb515494213
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.0.2/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-rUglwstkWzKtFUyscc0o6
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    hashable-1.4.3.0-GjMDKgDyLuqLq9SaBPRy7H mtl-2.2.2
    strict-list-0.1.7.4-JYA8OhOsVyXISnE0TJt5Zq

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deque-0.4.4.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deque
version:              0.4.4.1
visibility:           public
id:                   deque-0.4.4.1-99HVfMyAI2Q8luVGD2lMoX
key:                  deque-0.4.4.1-99HVfMyAI2Q8luVGD2lMoX
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  bede56d0a4a89dd553ef6c0e748217eb
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.0.2/site-local/deque-0.4.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deque-0.4.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.1-99HVfMyAI2Q8luVGD2lMoX
depends:
    base-4.15.1.0 deepseq-1.4.5.0
    hashable-1.4.3.0-33I0iRzN4K6CKLvpp4LZ7a mtl-2.2.2
    strict-list-0.1.7.4-9hHwxGtnv6b4WAfH3M7SjX

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
